/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.TimeZoneNamesBundle;

public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
    @Override
    protected final Object[][] getContents() {
        final String[] Cook = new String[] {
               "Saa za Wastani za Visiwa vya Cook",
               "",
               "Saa za Majira Nusu ya Joto za Visiwa vya Cook",
               "",
               "Saa za Visiwa vya Cook",
               "",
            };
        final String[] Cuba = new String[] {
               "Saa za Wastani za Kuba",
               "",
               "Saa za Mchana za Kuba",
               "",
               "Saa za Kuba",
               "",
            };
        final String[] Gulf = new String[] {
               "Saa za Wastani za Ghuba",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Iran = new String[] {
               "Saa za Wastani za Irani",
               "",
               "Saa za Mchana za Irani",
               "",
               "Saa za Irani",
               "",
            };
        final String[] Japan = new String[] {
               "Saa za Wastani za Japani",
               "",
               "Saa za Mchana za Japani",
               "",
               "Saa za Japani",
               "",
            };
        final String[] Nepal = new String[] {
               "Saa za Nepali",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Bhutan = new String[] {
               "Saa za Butani",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Easter = new String[] {
               "Saa za Wastani za Kisiwa cha Easter",
               "",
               "Saa za Majira ya Joto za Kisiwa cha Easter",
               "",
               "Saa za Kisiwa cha Easter",
               "",
            };
        final String[] ETC_UTC = new String[] {
               "Saa ya Ulimwenguni",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Georgia = new String[] {
               "Saa za Wastani za Jiojia",
               "",
               "Saa za Majira ya Joto za Jiojia",
               "",
               "Saa za Jiojia",
               "",
            };
        final String[] Myanmar = new String[] {
               "Saa za Myama",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Uruguay = new String[] {
               "Saa za Wastani za Urugwai",
               "",
               "Saa za Majira ya Joto za Urugwai",
               "",
               "Saa za Uruagwai",
               "",
            };
        final String[] Brasilia = new String[] {
               "Saa za Wastani za Brazili",
               "",
               "Saa za Majira ya Joto za Brazili",
               "",
               "Saa za Brazili",
               "",
            };
        final String[] Colombia = new String[] {
               "Saa za Wastani za Kolombia",
               "",
               "Saa za Majira ya Joto za Kolombia",
               "",
               "Saa za Kolombia",
               "",
            };
        final String[] Malaysia = new String[] {
               "Saa za Malesia",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Maldives = new String[] {
               "Saa za Maldivi",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mongolia = new String[] {
               "Saa za Wastani za Ulaanbataar",
               "",
               "Saa za Majira ya Joto za Ulaanbaatar",
               "",
               "Saa za Ulaanbataar",
               "",
            };
        final String[] Pakistan = new String[] {
               "Saa za Wastani za Pakistani",
               "",
               "Saa za Majira ya Joto za Pakistani",
               "",
               "Saa za Pakistani",
               "",
            };
        final String[] Paraguay = new String[] {
               "Saa za Wastani za Paragwai",
               "",
               "Saa za Majira ya Joto za Paragwai",
               "",
               "Saa za Paragwai",
               "",
            };
        final String[] Argentina = new String[] {
               "Saa za Wastani za Ajentina",
               "",
               "Saa za Majira Joto za Ajentina",
               "",
               "Saa za Ajentina",
               "",
            };
        final String[] Singapore = new String[] {
               "Saa za Wastani za Singapoo",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Azerbaijan = new String[] {
               "Saa za Wastani za Azabajani",
               "",
               "Saa za Majira ya Joto za Azabajani",
               "",
               "Saa za Azabajani",
               "",
            };
        final String[] Bangladesh = new String[] {
               "Saa za Wastani za Bangladeshi",
               "",
               "Saa za Majira ya Joto za Bangladeshi",
               "",
               "Saa za Bangladeshi",
               "",
            };
        final String[] Cape_Verde = new String[] {
               "Saa za Wastani za Kepuvede",
               "",
               "Saa za Majira ya Joto za Kepuvede",
               "",
               "Saa za Kepuvede",
               "",
            };
        final String[] Tajikistan = new String[] {
               "Saaza Tajikistani",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Uzbekistan = new String[] {
               "Saa za wastani za Uzbekistani",
               "",
               "Saa za Majira ya Joto za Uzbekistani",
               "",
               "Saa za Uzbekistani",
               "",
            };
        final String[] Afghanistan = new String[] {
               "Saa za Afghanistani",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] New_Zealand = new String[] {
               "Saa za Wastani za Nyuzilandi",
               "",
               "Saa za Mchana za Nyuzilandi",
               "",
               "Saa za Nyuzilandi",
               "",
            };
        final String[] Turkmenistan = new String[] {
               "Saa za Wastani za Turkmenistani",
               "",
               "Saa za Majira ya Joto za Turkmenistani",
               "",
               "Saa za Turkmenistani",
               "",
            };
        final String[] French_Guiana = new String[] {
               "Saa za Guiana",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] New_Caledonia = new String[] {
               "Saa za Wastani za Kaledonia Mpya",
               "",
               "Saa za Majira ya Joto za Kaledonia Mpya",
               "",
               "Saa za Kaledonia Mpya",
               "",
            };
        final String[] South_Georgia = new String[] {
               "Saa za Jojia Kusini",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Phoenix_Islands = new String[] {
               "Saa za Visiwa vya Finiksi",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mexico_Northwest = new String[] {
               "Saa za Wastani za Kaskazini Magharibi mwa Meksiko",
               "",
               "Saa za Mchana za Kaskazini Magharibi mwa Meksiko",
               "",
               "Saa za Kaskazini Magharibi mwa Meksiko",
               "",
            };
        final String[] Papua_New_Guinea = new String[] {
               "Saa za Papua",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kazakhstan_Eastern = new String[] {
               "Saa za Kazakistani Mashariki",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kazakhstan_Western = new String[] {
               "Saa za Kazakistani Magharibi",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Australia_CentralWestern = new String[] {
               "Saa za Wastani za Magharibi mwa Australia ya Kati",
               "",
               "Saa za Mchana za Magharibi mwa Australia ya Kati",
               "",
               "Saa za Magharibi mwa Austrialia ya Kati",
               "",
            };
        final Object[][] data = new Object[][] {
            { "Asia/Tokyo", Japan },
            { "UTC", ETC_UTC },
            { "BET", Brasilia },
            { "BST", Bangladesh },
            { "JST", Japan },
            { "NST", New_Zealand },
            { "PLT", Pakistan },
            { "Etc/UTC", ETC_UTC },
            { "Asia/Baku", Azerbaijan },
            { "Asia/Oral", Kazakhstan_Western },
            { "Asia/Aqtau", Kazakhstan_Western },
            { "Asia/Dhaka", Bangladesh },
            { "Asia/Dubai", Gulf },
            { "Asia/Kabul", Afghanistan },
            { "Asia/Almaty", Kazakhstan_Eastern },
            { "Asia/Aqtobe", Kazakhstan_Western },
            { "Asia/Atyrau", Kazakhstan_Western },
            { "Asia/Muscat", Gulf },
            { "Asia/Tehran", Iran },
            { "Asia/Karachi", Pakistan },
            { "Asia/Kuching", Malaysia },
            { "Asia/Rangoon", Myanmar },
            { "Asia/Tbilisi", Georgia },
            { "Asia/Thimphu", Bhutan },
            { "America/Bahia", Brasilia },
            { "America/Belem", Brasilia },
            { "America/Jujuy", Argentina },
            { "Asia/Ashgabat", Turkmenistan },
            { "Asia/Dushanbe", Tajikistan },
            { "Asia/Katmandu", Nepal },
            { "Asia/Qostanay", Kazakhstan_Eastern },
            { "Asia/Tashkent", Uzbekistan },
            { "America/Bogota", Colombia },
            { "America/Havana", Cuba },
            { "America/Maceio", Brasilia },
            { "America/Recife", Brasilia },
            { "Asia/Qyzylorda", Kazakhstan_Western },
            { "Asia/Samarkand", Uzbekistan },
            { "Asia/Singapore", Singapore },
            { "Pacific/Easter", Easter },
            { "Pacific/Noumea", New_Caledonia },
            { "America/Cayenne", French_Guiana },
            { "America/Cordoba", Argentina },
            { "America/Mendoza", Argentina },
            { "Asia/Choibalsan", Mongolia },
            { "Australia/Eucla", Australia_CentralWestern },
            { "Indian/Maldives", Maldives },
            { "America/Asuncion", Paraguay },
            { "America/Santarem", Brasilia },
            { "Asia/Ulaanbaatar", Mongolia },
            { "Pacific/Auckland", New_Zealand },
            { "America/Araguaina", Brasilia },
            { "America/Catamarca", Argentina },
            { "America/Fortaleza", Brasilia },
            { "America/Sao_Paulo", Brasilia },
            { "Asia/Kuala_Lumpur", Malaysia },
            { "Pacific/Enderbury", Phoenix_Islands },
            { "Pacific/Rarotonga", Cook },
            { "America/Montevideo", Uruguay },
            { "Antarctica/McMurdo", New_Zealand },
            { "Atlantic/Cape_Verde", Cape_Verde },
            { "America/Buenos_Aires", Argentina },
            { "America/Santa_Isabel", Mexico_Northwest },
            { "Pacific/Port_Moresby", Papua_New_Guinea },
            { "Antarctica/South_Pole", New_Zealand },
            { "Atlantic/South_Georgia", South_Georgia },
            { "America/Argentina/Salta", Argentina },
            { "America/Argentina/Tucuman", Argentina },
            { "America/Argentina/Ushuaia", Argentina },
            { "America/Argentina/La_Rioja", Argentina },
            { "America/Argentina/San_Juan", Argentina },
            { "America/Argentina/San_Luis", Argentina },
            { "timezone.excity.Asia/Macau", "Makao" },
            { "timezone.excity.Asia/Saigon", "Jiji la Ho Chi Minh" },
            { "timezone.excity.Asia/Colombo", "Kolombo" },
            { "timezone.excity.Asia/Rangoon", "Yangon" },
            { "America/Argentina/Rio_Gallegos", Argentina },
            { "timezone.excity.Asia/Singapore", "Singapoo" },
            { "timezone.excity.America/Jamaica", "Jamaika" },
            { "timezone.excity.Atlantic/Canary", "Kanari" },
            { "timezone.excity.Indian/Maldives", "Maldivi" },
            { "timezone.excity.America/Barbados", "Babadosi" },
            { "timezone.excity.America/Dominica", "Dominika" },
            { "timezone.excity.Atlantic/Bermuda", "Bamuda" },
            { "timezone.excity.Indian/Christmas", "Krismasi" },
            { "timezone.excity.America/Costa_Rica", "Kostarika" },
            { "timezone.excity.America/Guadeloupe", "Guadalupe" },
            { "timezone.excity.America/Martinique", "Matinikiu" },
            { "timezone.excity.America/El_Salvador", "Elsalvado" },
            { "timezone.excity.Antarctica/Macquarie", "Makwuarie" },
            { "timezone.excity.America/Port_of_Spain", "Bandari ya Uhispania" },
            { "timezone.excity.America/Port-au-Prince", "Bandari ya au-Prince" },
            { "timezone.excity.America/North_Dakota/Beulah", "Beulah, Dakota Kaskazini" },
            { "timezone.excity.America/North_Dakota/Center", "Center, Dakota Kaskazini" },
            { "timezone.excity.America/North_Dakota/New_Salem", "New Salem, Dakota Kaskazini" },
        };
        return data;
    }
}
